count_words: A function for counting words in an Rmarkdown document.

View source: R/count_words.R

count_wordsR Documentation

A function for counting words in an Rmarkdown document.

Description

This function takes a path to a .Rmd file and returns a word count. For best results each sentence should start on a new line. Inline code chunks should also start on a new line.

Usage

count_words(file)

Arguments

file

A path to a .Rmd file

Examples

# count_words("test.Rmd")

jvcasillas/academicWriteR documentation built on Dec. 28, 2024, 5:09 p.m.